function plotshore(filethread,step,modelrun)

%Function to create, plot and output an array of time step and shoreline
%position.
%Filethread specifies the output file folder in which the shoreline.mat
%file is located, e.g., output1, output2, etc. 
%Created by L. Moore 2/11/06

%cross platform file loading of shorelines.mat file
if(ispc)
   filename = ['../Output' num2str(filethread) '/shorelines.mat']; 
elseif(isunix)
   filename = ['../Output' num2str(filethread) '/shorelines.mat']; 
else
    error('Not Unix, Not PC!')
end

load(filename)

x = shorelines(:,1)./1000; %load shorelines data file and put in km
x(1,:)=[];

%step through shorelines and create new vector of corresponding time steps

last_time_step=((length(x))*step);% figure out the last time step value

t= [step:step:last_time_step]';%create a vector with time steps from 1 to last time step

temp=polyfit(t,x,1);
slope =temp(1);
slopemeters = slope*1000; %put migration rate into meters
intercept=temp(2);

fh = figure;
hold off;
plot(t(2:end),x(2:end));%plot all but first element
set (gca, 'XLim', [0 3000], 'YLim', [10 100])
set (gca,  'yminortick','on',...
    'xminortick','on',...
    'TickDir','out')
xlabel('Time (years)','FontSize',15);
ylabel('Shoreline Position (km)','FontSize',15);    
title((modelrun), 'fontsize', 18) 

hold on;

text(500,80,['Migration Rate = ' num2str(slopemeters, 2) ' m/yr'],'fontsize',15)
text(500,70,['Final Shore Position = ' num2str(x(end), 3) ' km'], 'fontsize', 15)
% text(t(3),max(x)*1.2,['Migration Rate =' num2str(slopemeters, 2) ' m/yr'], 'fontsize', 15);
% text(t(3),max(x)*1.1,['Final Shore Position =' num2str(x(end), 3) ' km'], 'fontsize', 15);

%create matrix A containing time steps and shoreline position for output
%later

A = [t,x];

save x t

saveas(fh, ['../Output' num2str(filethread) '/pshore' num2str(modelrun) '.fig'])

outputfilename = ['../Output' num2str(filethread) '/pshore' num2str(modelrun)];

%print('-dill',outputfilename)
print('-dpdf',outputfilename)
print('-djpeg',outputfilename)
print('-dpng',outputfilename)